-- FEEL FREE TO MODIFY THE BELOW BINDINGS AS DESIRED
-- All keys must be surrounded by quotes "".
-- Examples: "F1" is the 'F1' key on your keyboard.
-- To combine keys, you add dashes like: "ALT-F" or "CTRL-SHIFT-F5"
-- To use mouse buttons instead of keys: "BUTTON2" (for right-click) or "BUTTON5" (for your fifth mouse button)
-- To use keys on the Num Pad, add "NUMPAD" in front of the key. For example, "NUMPAD4" or "NUMPADPLUS".
-- If you want to use a button that isn't listed above as an example, go into WoW's key binding options and see what it looks like there.
-- Then remove the spaces and capitialize everything, and it should be in the correct format.

local BPB_Binds = { -- code below this line is ok to change
["BPB_ACTIONBUTTON1"] = "1",
["BPB_ACTIONBUTTON2"] = "2",
["BPB_ACTIONBUTTON3"] = "3",
["BPB_ACTIONBUTTON4"] = "4",
["BPB_ACTIONBUTTON5"] = "5",
["BPB_CHANGEPET1"] = "F1",
["BPB_CHANGEPET2"] = "F2",
["BPB_CHANGEPET3"] = "F3",
["BPB_SKIPTURN"] = "R",
["BPB_FORFEIT"] = "F",
} -- code above this line is ok to change

------------------------------
-- Addon code starts below  --
------------------------------

-- use boolean variable to account for Blizzard event misfire bug
local BPB_BindState = false

-- create event handling frame
local BattlePetBinds = CreateFrame("FRAME", "BattlePetBinds")

-- register events
BattlePetBinds:RegisterEvent("ADDON_LOADED")
BattlePetBinds:RegisterEvent("PET_BATTLE_OPENING_START")
BattlePetBinds:RegisterEvent("PET_BATTLE_OPENING_DONE")
BattlePetBinds:RegisterEvent("PET_BATTLE_OVER")
BattlePetBinds:RegisterEvent("PET_BATTLE_CLOSE")

-- event handler function
local function BattlePetBinds_OnEvent(self, event, ...)
	-- if this addon loads and we're not in combat and we're in a pet battle then
	if (event == "ADDON_LOADED") and (... == "Battle Pet Binds") and not InCombatLockdown() and C_PetBattles.IsInBattle() then
		-- set up our override bindings
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON1"], "BPB_ACTIONBUTTON1")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON2"], "BPB_ACTIONBUTTON2")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON3"], "BPB_ACTIONBUTTON3")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON4"], "BPB_ACTIONBUTTON4")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON5"], "BPB_ACTIONBUTTON5")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_CHANGEPET1"], "BPB_CHANGEPET1")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_CHANGEPET2"], "BPB_CHANGEPET2")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_CHANGEPET3"], "BPB_CHANGEPET3")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_SKIPTURN"], "BPB_SKIPTURN")
		SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_FORFEIT"], "BPB_FORFEIT")
		-- tell the boolean we have set our bindings
		BPB_BindState = true
	-- if we start a pet battle and are not in combat then (checking both opening events to account for Blizzard event misfire bug)
	elseif ((event == "PET_BATTLE_OPENING_START") or (event == "PET_BATTLE_OPENING_DONE")) and not InCombatLockdown() then
		-- if our boolean shows we haven't set binds then
		if (BPB_BindState == false) then
			-- set up our override bindings
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON1"], "BPB_ACTIONBUTTON1")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON2"], "BPB_ACTIONBUTTON2")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON3"], "BPB_ACTIONBUTTON3")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON4"], "BPB_ACTIONBUTTON4")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_ACTIONBUTTON5"], "BPB_ACTIONBUTTON5")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_CHANGEPET1"], "BPB_CHANGEPET1")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_CHANGEPET2"], "BPB_CHANGEPET2")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_CHANGEPET3"], "BPB_CHANGEPET3")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_SKIPTURN"], "BPB_SKIPTURN")
			SetOverrideBinding(BattlePetBinds, true, BPB_Binds["BPB_FORFEIT"], "BPB_FORFEIT")
			-- tell the boolean we have set our bindings
			BPB_BindState = true
		end
	-- if the pet battle ends then (checking both closing events to account for Blizzard event misfire bug)
	elseif (event == "PET_BATTLE_OVER") or (event == "PET_BATTLE_CLOSE") then
		-- if our boolean shows we have set binds then
		if (BPB_BindState == true) then
			-- remove our bindings
			ClearOverrideBindings(BattlePetBinds)
			-- tell the boolean that we have removed our bindings
			BPB_BindState = false
		end
	end
end

-- set our event handler function
BattlePetBinds:SetScript("OnEvent", BattlePetBinds_OnEvent)